@@ -18,11 +18,11 @@ Queue::DBI::Admin - Manage Queue::DBI queues.
 
 =head1 VERSION
 
-Version 2.3.0
+Version 2.3.1
 
 =cut
 
-our $VERSION = '2.3.0';
+our $VERSION = '2.3.1';
 
 
 =head1 SYNOPSIS
@@ -321,36 +321,29 @@ sub delete_queue
 
 Determine if the tables required for L<Queue::DBI> to operate exist.
 
-In scalar context, this method returns a boolean indicating whether all the
-necessary tables exist:
-
-	# Determine if the tables exist.
 	my $tables_exist = $queues_admin->has_tables();
 
-In list context, this method returns a boolean indicating whether all the
-necessary tables exist, and an arrayref of the name of the missing table(s) if
-any:
-
-	# Determine if the tables exist, and the missing one(s).
-	my ( $tables_exist, $missing_tables ) = $queues_admin->has_tables();
+This method returns 1 if all tables exist, 0 if none exist, and croaks with
+more information if some tables are missing or if the mandatory fields on some
+of the tables are missing.
 
 =cut
 
 sub has_tables
 {
 	my ( $self ) = @_;
-	my $missing_tables = [];
-	
 	my $database_handle = $self->get_database_handle();
 	
 	# Check the database type.
 	$self->assert_database_type_supported();
 	
 	# Check if the queues table exists.
+	my $queues_table_exists =
 	try
 	{
 		# Disable printing errors out since we expect the statement to fail.
 		local $database_handle->{'PrintError'} = 0;
+		local $database_handle->{'RaiseError'} = 1;
 		
 		$database_handle->selectrow_array(
 			sprintf(
@@ -361,17 +354,21 @@ sub has_tables
 				$self->get_quoted_queues_table_name(),
 			)
 		);
+		
+		return 1;
 	}
 	catch
 	{
-		push( @$missing_tables, $self->get_queues_table_name() );
+		return 0;
 	};
 	
 	# Check if the queue elements table exists.
+	my $queue_elements_table_exists =
 	try
 	{
 		# Disable printing errors out since we expect the statement to fail.
 		local $database_handle->{'PrintError'} = 0;
+		local $database_handle->{'RaiseError'} = 1;
 		
 		$database_handle->selectrow_array(
 			sprintf(
@@ -382,16 +379,84 @@ sub has_tables
 				$self->get_quoted_queue_elements_table_name(),
 			)
 		);
+		
+		return 1;
 	}
 	catch
 	{
-		push( @$missing_tables, $self->get_queue_elements_table_name() );
+		return 0;
 	};
 	
-	my $tables_exist = scalar( @$missing_tables ) == 0 ? 1 : 0;
-	return wantarray()
-		? ( $tables_exist, $missing_tables )
-		: $tables_exist;
+	# If both tables don't exist, return 0.
+	return 0
+		if !$queues_table_exists && !$queue_elements_table_exists;
+	
+	# If one of the tables is missing, we want the user to know that there is
+	# a problem to fix and that create_table() won't work.
+	croak "The table '" . $self->get_queues_table_name() . "' exists, but '" . $self->get_queue_elements_table_name() . "' is missing"
+		if $queues_table_exists && !$queue_elements_table_exists;
+	croak "The table '" . $self->get_queue_elements_table_name() . "' exists, but '" . $self->get_queues_table_name() . "' is missing"
+		if !$queues_table_exists && $queue_elements_table_exists;
+	
+	# Check if the queues table has the mandatory fields.
+	my $queues_table_has_fields =
+	try
+	{
+		# Disable printing errors out since we expect the statement to fail.
+		local $database_handle->{'PrintError'} = 0;
+		local $database_handle->{'RaiseError'} = 1;
+		
+		$database_handle->selectrow_array(
+			sprintf(
+				q|
+					SELECT queue_id, name
+					FROM %s
+				|,
+				$self->get_quoted_queues_table_name(),
+			)
+		);
+		
+		return 1;
+	}
+	catch
+	{
+		return 0;
+	};
+	
+	croak "The table '" . $self->get_queues_table_name() . "' exists, but is missing mandatory fields"
+		if !$queues_table_has_fields;
+	
+	# Check if the queue elements table has the mandatory fields.
+	my $queue_elements_table_has_fields =
+	try
+	{
+		# Disable printing errors out since we expect the statement to fail.
+		local $database_handle->{'PrintError'} = 0;
+		local $database_handle->{'RaiseError'} = 1;
+		
+		$database_handle->selectrow_array(
+			sprintf(
+				q|
+					SELECT queue_element_id, queue_id, data, lock_time, requeue_count, created
+					FROM %s
+				|,
+				$self->get_quoted_queue_elements_table_name(),
+			)
+		);
+		
+		return 1;
+	}
+	catch
+	{
+		return 0;
+	};
+	
+	croak "The table '" . $self->get_queue_elements_table_name() . "' exists, but is missing mandatory fields"
+		if !$queue_elements_table_has_fields;
+	
+	# Both tables exist and have the mandatory fields for Queue::DBI to
+	# work, we can safely return 1.
+	return 1;
 }
 
 
